package com.zulutrade.sample.trading.client.sender;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.concurrent.TimeUnit;

import sun.misc.BASE64Encoder;
import com.zulutrade.sample.trading.client.configuration.ZuluTradeAuthenticationInfo;
import com.zulutrade.sample.trading.client.configuration.ZuluTradingServerConfig;

/**
 * Utility class used to send rest calls
 * to a trading server
 * @author ZuluTrade
 */
public class TradingResquestsSender {

	/**
	 * Sends a trading request to the trading server provided
	 * using basic http authentication
	 * 
	 * @param config Holder of Zulu's trading server info 
	 * @param authenticationsInfo Holder of Zulu credentials
	 * @param tradingRequest trading request as a rest call string
	 * @return the server response as string
	 * @throws Exception
	 */
	public static String sendRequest(ZuluTradingServerConfig config, ZuluTradeAuthenticationInfo authenticationsInfo, String tradingRequest) throws Exception{
		HttpURLConnection connection = null;
		URL url = new URL (config.getTradingServicesUrl()+tradingRequest);
		String encoding = new BASE64Encoder().encode((authenticationsInfo.getZuluAccountUsername()+":"+authenticationsInfo.getZuluAccountPassword()).getBytes());
		connection = (HttpURLConnection) url.openConnection();
		connection.setRequestMethod("GET");
		connection.setDoOutput(true);
		connection.setRequestProperty  ("Authorization", "Basic " + encoding);
		connection.setReadTimeout((int)TimeUnit.MINUTES.toMillis(5));
		connection.setConnectTimeout((int)TimeUnit.MINUTES.toMillis(5));
		InputStream content = (InputStream)connection.getInputStream();
		BufferedReader in = new BufferedReader (new InputStreamReader (content));
		String line;
		StringBuilder result = new StringBuilder();
		while((line = in.readLine()) != null) {
			result.append(line);
		}
		return result.toString();
	}
	
}
